{
  pkgs,
  ...
}: {
  programs.nixvim = {
    enable = true;
    colorschemes.ayu = {
      enable = true;
      settings = {
        mirage = true;
        overrides = {
          LineNr = { fg = "#707A8C"; };
        };
      };
    };
    clipboard = {
      providers.wl-copy.enable = true;
      register = "unnamedplus";
    };
    extraPackages = with pkgs; [
      latexrun
      zathura
    ];
    options = {
      number = true;
      relativenumber = true;
      tabstop = 2;
      shiftwidth = 2;
      expandtab = false;
      scrolloff = 5;
      autoindent = true;
      smartindent = true;
      copyindent = true;
      signcolumn = "yes";
      cursorline = true;
      showmode = false;
    };
    plugins = {
      telescope = {
        enable = true;
      };
      comment-nvim = {
        enable = true;
      };
      markdown-preview = {
        enable = true;
        settings.browser = "firefox";
      };
      lualine = {
        enable = true;
        sectionSeparators = {
          left = "";
          right = "";
        };
        componentSeparators = {
          left = "•";
          right = "•";
        };
      };
      lsp = {
        enable = true;
        servers = {
          nil_ls = {
            enable = true;
          };
        };
      };
      cmp = {
        enable = true;
        settings = {
          sources = [
            { name = "nvim_lsp"; }
            { name = "treesitter"; }
            { name = "luasnip"; }
            { name = "latex_symbols"; }
            { name = "path"; }
            { name = "buffer"; }
          ];
          snippet.expand = "luasnip";
          completion = {
            autocomplete = false;
          };
          mapping = {
            "<C-Space>" = "cmp.mapping.complete()";
            "<C-e>" = "cmp.mapping.close()";
            "<CR>" = "cmp.mapping.confirm({ select = true })";
            "<C-b>" = "cmp.mapping.scroll_docs(-4)";
            "<C-f>" = "cmp.mapping.scroll_docs(4)";
            "<C-p>" = "cmp.mapping(cmp.mapping.select_prev_item(), {'i', 's'})";
            "<C-n>" = "cmp.mapping(cmp.mapping.select_next_item(), {'i', 's'})";
          };
        };
      };
      luasnip = {
        enable = true;
      };
      friendly-snippets.enable = true;
      gitsigns = {
        enable = true;
      };
      treesitter = {
        enable = true;
        nixvimInjections = true;
        indent = true;
        disabledLanguages = [
          "latex"
        ];
        ignoreInstall = [
          "latex"
        ];
      };
      vimtex = {
        enable = true;
        texlivePackage = pkgs.texliveFull;
        settings = {
          compiler_method = "latexrun";
          view_method = "zathura";
        };
      };
    };
    files = {
      "ftplugin/nix.lua" = {
        options = {
          expandtab = true;
          shiftwidth = 2;
          tabstop = 2;
        };
      };
      "ftplugin/markdown.lua" = {
        options = {
          spell = true;
        };
      };
      "ftplugin/tex.lua" = {
        options = {
          spell = true;
        };
      };
    };
    keymaps = [
      {
        action = "<cmd>nohl<CR>";
        key = "<C-q>";
        options.silent = true;
      }
    ];
  };
}
